import 'package:flutter/material.dart';
import 'package:onairos/biometricKey.dart';
import 'overlay.dart';
import 'NoOnairos.dart';


// /Main imported Onaiors button component
class OnairosButtonWrapper2 extends StatefulWidget {
  final Map<String, Map<String, String>> requestData;
  final String returnLink;

  const OnairosButtonWrapper2({
    Key? key,
    required this.requestData,
    required this.returnLink,
  }) : super(key: key);

  @override
  _OnairosButtonWrapperState createState() => _OnairosButtonWrapperState();
}

class _OnairosButtonWrapperState extends State<OnairosButtonWrapper2> {
  Future<void> _openOnairosOverlay(BuildContext context, Function onResolved) async {

    // Only authorized user can initiate data grant
    SecureAuthService authService = SecureAuthService();
    bool authenticated = await authService.authenticate();
    if(!authenticated){
      Navigator.pop(context);
      return;
    }

    // Get PIN and username from Biometric Secure storage
    String? username = await authService.retrieveKey("username");
    String? key = await authService.retrieveKey("key");
    
    try {
      if (username != null && key != null) {
        showModalBottomSheet(
          context: context,
          backgroundColor: Colors.transparent,
          builder: (context) => OnairosOverlay(
            data: widget.requestData.isNotEmpty ? widget.requestData : { 'default': 'No data' },
            username: username,
            modelKey: key,
            onResolved: onResolved,
          ),
        );
      }  else {
          // Show the error modal if the username or key is null
          showModalBottomSheet(
            context: context,
            backgroundColor: Colors.transparent,
            builder: (BuildContext context) => OnairosPromptModal(
              onClose: () => Navigator.of(context).pop(),
              logoPath: 'assets/images/onairos_logo.png', // Ensure you have the logo image in your assets
            ),
          );
        }
    } catch (e) {
      // Handle any other exceptions that might occur
      showErrorModal(context, 'An error occurred: $e');
      throw 'Could not overlay with ${widget.requestData}';
    }
  }

  void showErrorModal(BuildContext context, String errorMessage) {
    if (mounted) {
      showDialog(
        context: context,
        builder: (context) {
          return AlertDialog(
            title: Text('Error'),
            content: Text(errorMessage),
            actions: [
              TextButton(
                onPressed: () => Navigator.of(context).pop(),
                child: Text('OK'),
              ),
            ],
          );
        },
      );
    }
  }

  @override
  Widget build(BuildContext context) {
    // Rendere Onairs Button
    return OnairosButton2(
      requestData: widget.requestData,
      returnLink: widget.returnLink,
      openOnairosOverlay: _openOnairosOverlay,
      // Would be from initialization from partnered app
      onResolved: (apiUrl) {
        // App2 can define how to handle the apiUrl here
      },
    );
  }
}

// Rendered Button which user clicks to open overlay and initiate data request
class OnairosButton2 extends StatelessWidget {
  final Map<String, Map<String, String>> requestData;
  final String returnLink;
  final Function onResolved;
  final Future<void> Function(BuildContext context, Function onResolved) openOnairosOverlay;

  const OnairosButton2({
    Key? key,
    required this.requestData,
    required this.onResolved,
    required this.returnLink,
    required this.openOnairosOverlay,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ElevatedButton(
      onPressed: () => openOnairosOverlay(context, onResolved),
      child: Image.asset('images/onairos_logo.png'),
      style: ElevatedButton.styleFrom(
        foregroundColor: Colors.grey,
        backgroundColor: Colors.white,
        shape: CircleBorder(),
        padding: EdgeInsets.all(10),
      ),
    );
  }
}